package com.aucma.dms.service;

//import com.aucma.dms.domain.DmsBaseDeviceSupplies;

import com.aucma.dms.domain.DmsBaseDeviceSupplies;

import java.util.List;

/**
 * 设备配套信息Service接口
 * 
 * @author zangch
 * @date 2024-09-19
 */
public interface IDmsBaseDeviceSuppliesService 
{
    /**
     * 查询设备配套信息
     * 
     * @param deviceSuppliesId 设备配套信息主键
     * @return 设备配套信息
     */
    public DmsBaseDeviceSupplies selectDmsBaseDeviceSuppliesByDeviceSuppliesId(Long deviceSuppliesId);

    /**
     * 查询设备配套信息列表
     * 
     * @param dmsBaseDeviceSupplies 设备配套信息
     * @return 设备配套信息集合
     */
    public List<DmsBaseDeviceSupplies> selectDmsBaseDeviceSuppliesList(DmsBaseDeviceSupplies dmsBaseDeviceSupplies);

    /**
     * 新增设备配套信息
     * 
     * @param dmsBaseDeviceSupplies 设备配套信息
     * @return 结果
     */
    public int insertDmsBaseDeviceSupplies(DmsBaseDeviceSupplies dmsBaseDeviceSupplies);

    /**
     * 修改设备配套信息
     * 
     * @param dmsBaseDeviceSupplies 设备配套信息
     * @return 结果
     */
    public int updateDmsBaseDeviceSupplies(DmsBaseDeviceSupplies dmsBaseDeviceSupplies);

    /**
     * 批量删除设备配套信息
     * 
     * @param deviceSuppliesIds 需要删除的设备配套信息主键集合
     * @return 结果
     */
    public int deleteDmsBaseDeviceSuppliesByDeviceSuppliesIds(Long[] deviceSuppliesIds);

    /**
     * 删除设备配套信息信息
     * 
     * @param deviceSuppliesId 设备配套信息主键
     * @return 结果
     */
    public int deleteDmsBaseDeviceSuppliesByDeviceSuppliesId(Long deviceSuppliesId);

    public List<DmsBaseDeviceSupplies> selectDmsBaseDeviceSuppliesListByDeviceId(Long deviceId);
}
